Road Collisions
===============

Only Irish roads at the moment but will name to allow for scope.

# Quickstart

To enter a debugger with access to all collision data run `make load` and you will have access to the variable `collisions` which contains everything
